==> aliyun-tools-0.0.1-20180716.021925-6-sources.jar: com/jz/aliyun/beans/StsTokenConfig.java <==
package com.jz.aliyun.beans;

/**
 * @Title StsTokenConfig
 * @Package com.jz.aliyun.beans
 * @author tangjunfeng
 * @date 2018年7月12日 上午11:27:41
 * @version V1.0
 */
public class StsTokenConfig {

	private String basePath;
	private String saveDir;
	private String ext;
	private String cdnHost;
	private String callback;
	private String callbackBody;
	private int tokenExpireSeconds;
	private boolean enableHttps;
	
	public static StsTokenConfig of() {
		return new StsTokenConfig();
	}
	
	public String getBasePath() {
		return basePath;
	}

	public StsTokenConfig setBasePath(String basePath) {
		this.basePath = basePath;
		return this;
	}

	public String getSaveDir() {
		return saveDir;
	}

	public StsTokenConfig setSaveDir(String saveDir) {
		this.saveDir = saveDir;
		return this;
	}

	public String getExt() {
		return ext;
	}

	public StsTokenConfig setExt(String ext) {
		this.ext = ext;
		return this;
	}

	public String getCdnHost() {
		return cdnHost;
	}

	public StsTokenConfig setCdnHost(String cdnHost) {
		this.cdnHost = cdnHost;
		return this;
	}

	public String getCallback() {
		return callback;
	}

	public StsTokenConfig setCallback(String callback) {
		this.callback = callback;
		return this;
	}

	public String getCallbackBody() {
		return callbackBody;
	}

	public StsTokenConfig setCallbackBody(String callbackBody) {
		this.callbackBody = callbackBody;
		return this;
	}

	public int getTokenExpireSeconds() {
		return tokenExpireSeconds;
	}

	public StsTokenConfig setTokenExpireSeconds(int tokenExpireSeconds) {
		this.tokenExpireSeconds = tokenExpireSeconds;
		return this;
	}

	public boolean isEnableHttps() {
		return enableHttps;
	}

	public StsTokenConfig setEnableHttps(boolean enableHttps) {
		this.enableHttps = enableHttps;
		return this;
	}

}

==> aliyun-tools-0.0.2-20180820.080151-1-sources.jar: com/jz/aliyun/beans/StsTokenConfig.java <==
package com.jz.aliyun.beans;

/**
 * @Title StsTokenConfig
 * @Package com.jz.aliyun.beans
 * @author tangjunfeng
 * @date 2018年7月12日 上午11:27:41
 * @version V1.0
 */
public class StsTokenConfig {

	private String basePath;
	private String saveDir;
	private String ext;
	private String prefix;
	private String cdnHost;
	private String callback;
	private String callbackBody;
	private int tokenExpireSeconds;
	private boolean enableHttps;

	public static StsTokenConfig of() {
		return new StsTokenConfig();
	}

	public String getBasePath() {
		return basePath;
	}

	public StsTokenConfig setBasePath(String basePath) {
		this.basePath = basePath;
		return this;
	}

	public String getSaveDir() {
		return saveDir;
	}

	public StsTokenConfig setSaveDir(String saveDir) {
		this.saveDir = saveDir;
		return this;
	}

	public String getExt() {
		return ext;
	}

	public StsTokenConfig setExt(String ext) {
		this.ext = ext;
		return this;
	}

	public String getPrefix() {
		return prefix;
	}

	public StsTokenConfig setPrefix(String prefix) {
		this.prefix = prefix;
		return this;
	}

	public String getCdnHost() {
		return cdnHost;
	}

	public StsTokenConfig setCdnHost(String cdnHost) {
		this.cdnHost = cdnHost;
		return this;
	}

	public String getCallback() {
		return callback;
	}

	public StsTokenConfig setCallback(String callback) {
		this.callback = callback;
		return this;
	}

	public String getCallbackBody() {
		return callbackBody;
	}

	public StsTokenConfig setCallbackBody(String callbackBody) {
		this.callbackBody = callbackBody;
		return this;
	}

	public int getTokenExpireSeconds() {
		return tokenExpireSeconds;
	}

	public StsTokenConfig setTokenExpireSeconds(int tokenExpireSeconds) {
		this.tokenExpireSeconds = tokenExpireSeconds;
		return this;
	}

	public boolean isEnableHttps() {
		return enableHttps;
	}

	public StsTokenConfig setEnableHttps(boolean enableHttps) {
		this.enableHttps = enableHttps;
		return this;
	}

}
